/* $Header: /cvsroot/ensemble/maestro/src/type/Maestro.h,v 1.2 2001/11/06 10:09:46 orodeh Exp $
 *
 * Contents: Standard header file for Maestro/Ensemble applications.
 *
 * Author:  Alexey Vaysburd, January 1997
 */

#ifndef __MAESTRO_H__
#define __MAESTRO_H__

#include "Maestro_Types.h"
#include "Maestro_GroupMember.h"
#include "Maestro_ClSv.h"
#include "Maestro_CSX.h"
#include "Maestro_Prim.h"
#include "Maestro_Perf.h"
#include "Maestro_CORBA.h"
#include "Maestro_ETC.h"
#include "Maestro_GIOP.h"
#include "Maestro_IIOPBridge.h"
#include "Maestro_ORB.h"
#include "Maestro_Adaptor.h"
#include "Maestro_ES_ReplicatedUpdates.h"
#include "Maestro_ES_Simple.h"

#endif //__MAESTRO_H__
